==> haskell-hasql-0.19.15.2-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hasql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql
version: 0.19.15.2
id: hasql-0.19.15.2-6g7TAZ0bidoFWJlx7ATe2G
key: hasql-0.19.15.2-6g7TAZ0bidoFWJlx7ATe2G
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql
synopsis: An efficient PostgreSQL driver and a flexible mapping API
description:
    This package is the root of the \"hasql\" ecosystem.
    .
    The API is completely disinfected from exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    Hasql.Decoders Hasql.Encoders Hasql.Connection Hasql.Query
    Hasql.Session
hidden-modules: Hasql.Private.Prelude Hasql.Private.PTI
                Hasql.Private.IO Hasql.Private.Query Hasql.Private.Session
                Hasql.Private.Connection Hasql.Private.PreparedStatementRegistry
                Hasql.Private.Settings Hasql.Private.Commands
                Hasql.Private.Decoders.Array Hasql.Private.Decoders.Composite
                Hasql.Private.Decoders.Value Hasql.Private.Decoders.Row
                Hasql.Private.Decoders.Result Hasql.Private.Decoders.Results
                Hasql.Private.Encoders.Array Hasql.Private.Encoders.Value
                Hasql.Private.Encoders.Params
abi: 119e268e5c034ddcf6204740774649e1
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hasql-0.19.15.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/hasql-0.19.15.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/hasql-0.19.15.2
hs-libraries: HShasql-0.19.15.2-6g7TAZ0bidoFWJlx7ATe2G
depends:
    aeson-1.0.2.1-APwMyQyIboIL2RMSmpN5uA
    attoparsec-0.13.1.0-8poMzD5ooNXJ4NDLaelDWq base-4.9.0.0
    base-prelude-1.0.1.1-50PByGWQp6O3J1SglYyZmP bytestring-0.10.8.1
    bytestring-tree-builder-0.2.7.1-Hg4hwy5P5lFBOPT91IVLB2
    contravariant-1.4-89BvpwBnlCJ6iFzBGVF7XO
    contravariant-extras-0.3.3.1-3VH167ELHmzYXnWPlpDk9
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    dlist-0.8.0.2-GWAMmbX9rLg3tqrbOizHGv
    either-4.4.1.1-6l0lf0jupinGQdYUxKNQra
    hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
    hashtables-1.2.1.0-AaXmM36fMlN6f2RbFgLszy
    loch-th-0.2.1-HeAYtId6vjrGaOk8hiaVQf
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    placeholders-0.1-Jaw2KlzCEKg3F0WJS0H8eo
    postgresql-binary-0.9.1.1-AEEfPVsFKuqJQL6mdgfCZh
    postgresql-libpq-0.9.2.0-pfIR3xRbgN3lAiV2rvAZp
    profunctors-5.2-CUL7kUu4nBbDVNmgOaH64k
    scientific-0.3.4.9-Ghl8M4Ey2fMI7e1yk2TuuH
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0 uuid-1.3.13-FGB0FzlnaHLK9XopYKf5iZ
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html: /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-0.19.15.2-14-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hasql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql
version: 0.19.15.2
id: hasql-0.19.15.2-EXX4nStnv8PPlHClqhylO
key: hasql-0.19.15.2-EXX4nStnv8PPlHClqhylO
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql
synopsis: An efficient PostgreSQL driver and a flexible mapping API
description:
    This package is the root of the \"hasql\" ecosystem.
    .
    The API is completely disinfected from exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    Hasql.Decoders Hasql.Encoders Hasql.Connection Hasql.Query
    Hasql.Session
hidden-modules: Hasql.Private.Prelude Hasql.Private.PTI
                Hasql.Private.IO Hasql.Private.Query Hasql.Private.Session
                Hasql.Private.Connection Hasql.Private.PreparedStatementRegistry
                Hasql.Private.Settings Hasql.Private.Commands
                Hasql.Private.Decoders.Array Hasql.Private.Decoders.Composite
                Hasql.Private.Decoders.Value Hasql.Private.Decoders.Row
                Hasql.Private.Decoders.Result Hasql.Private.Decoders.Results
                Hasql.Private.Encoders.Array Hasql.Private.Encoders.Value
                Hasql.Private.Encoders.Params
abi: 39950e4551b344a68c3618905b553780
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hasql-0.19.15.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/hasql-0.19.15.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/hasql-0.19.15.2
hs-libraries: HShasql-0.19.15.2-EXX4nStnv8PPlHClqhylO
depends:
    aeson-1.0.2.1-FRh8NWzqPiiuj2q5G5H5S
    attoparsec-0.13.1.0-IbZnQWsljer1cy7HS9Csat base-4.9.0.0
    base-prelude-1.0.1.1-50PByGWQp6O3J1SglYyZmP bytestring-0.10.8.1
    bytestring-tree-builder-0.2.7.1-Hg4hwy5P5lFBOPT91IVLB2
    contravariant-1.4-QSyIMKSTFU5sk4KxSecCX
    contravariant-extras-0.3.3.1-46YJRgX9aI57kKWtOAUQwe
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    dlist-0.8.0.2-GWAMmbX9rLg3tqrbOizHGv
    either-4.4.1.1-EbNPoaWgoOPDzN8mAfWK3D
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    hashtables-1.2.1.0-KpD1dORkz4bFlaOoTGiVHI
    loch-th-0.2.1-HeAYtId6vjrGaOk8hiaVQf
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    placeholders-0.1-Jaw2KlzCEKg3F0WJS0H8eo
    postgresql-binary-0.9.1.1-25O7aVeZ3ejAxKa8zusyOE
    postgresql-libpq-0.9.3.0-3hQCxFsBezA9tQ0YdNvQt
    profunctors-5.2-5RA339bRfsXIbryi2lNqpM
    scientific-0.3.4.9-1EMxAMphVKV1cR2UEyLvhJ
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0 uuid-1.3.13-LNkd6YXQyKMLQFcm1B39cg
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html: /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
